@@ -3,10 +3,10 @@ namespace Iranserver\ApiServiceProvider;
 
 use GuzzleHttp\Client;
 use GuzzleHttp\Exception\GuzzleException;
-use Illuminate\Http\Client\HttpClientException;
 use Exception;
 use Illuminate\Support\Traits\Macroable;
 use Psr\Http\Message\ResponseInterface;
+use Iranserver\ApiServiceProvider\Exceptions\ResellerException;
 
 class Api extends Client
 {
@@ -20,8 +20,7 @@ class Api extends Client
             session()->forget('api');
             $this->delete('logout');
         }
-        catch (GuzzleException $e) {}
-        catch (Exception $e) {}
+        catch (GuzzleException | Exception $e) {}
     }
 
     public function login($username, $password, $scopes = []): array
@@ -39,12 +38,13 @@ class Api extends Client
         $content = $response->getBody()->getContents();
         $responseArray = json_decode($content, true);
 
-        if ($error = data_get($responseArray, 'error.message')) {
+        if (isset($responseArray['error'])) {
             /** @noinspection PhpUnhandledExceptionInspection Should handle in app */
-            throw new HttpClientException($error);
+            throw ResellerException::fromResponse($responseArray);
         }
 
         if (isset($responseArray['access_token'])) {
+            $this->setToken($responseArray['access_token']);
             session()->put('api', $responseArray);
             return $responseArray;
         }
@@ -55,8 +55,7 @@ class Api extends Client
 
     public function loginWithId($id, $scopes = []): array
     {
-        /** @noinspection PhpUnhandledExceptionInspection Should handle in app */
-        $response = $this->post('createToken', ['form_params' => [
+        $response = app(P2P::class)->post('createToken', ['form_params' => [
             'name'          => 'Domain Password Grant Client',
             'client_id'     => config('api.client_id'),
             'client_secret' => config('api.client_secret'),
@@ -67,12 +66,13 @@ class Api extends Client
         $content = $response->getBody()->getContents();
         $responseArray = json_decode($content, true);
 
-        if ($error = data_get($responseArray, 'error.message')) {
+        if (isset($responseArray['error'])) {
             /** @noinspection PhpUnhandledExceptionInspection Should handle in app */
-            throw new HttpClientException($error);
+            throw ResellerException::fromResponse($responseArray);
         }
 
         if (isset($responseArray['data']['access_token'])) {
+            $this->setToken($responseArray['data']['access_token']);
             session()->put('api', $responseArray['data']);
             return $responseArray['data'];
         }
